module config_m

  use jumble, only: pi

  implicit none

  real, protected:: min_amp = 0.001
  ! minimum amplitude of ssh, between extremum and outermost contour,
  ! in m

  integer, protected:: max_radius(2) = [20, 20]
  ! maximum radius of an eddy in number of grid points. Beware: run
  ! time is roughly proportional to product(max_radius). If periodic
  ! then max_radius(1) must be < nlon / 4.

  real, protected, save:: min_area ! minimum area of an outermost contour, in m2

  private pi

contains

  subroutine config

    use, intrinsic:: ISO_FORTRAN_ENV

    ! Libraries:
    use jumble, only: new_unit

    ! Local:

    logical exist
    integer unit, iostat

    real:: min_radius = 25.
    ! minimum radius of the equal-area disk for an outermost contour, in km

    namelist /config_nml/ min_amp, max_radius, min_radius
    character(len = 1000) iomsg

    !----------------------------------------------------------------------

    inquire(file = "SHPC/used_config_nml.txt", exist = exist)
    call new_unit(unit)

    if (exist) then
       print *, "config: Found SHPC/used_config_nml.txt"
       open(unit, file = "SHPC/used_config_nml.txt", status = "old", &
            action = "read", position = "rewind")
       read(unit, nml = config_nml)
       close(unit)
    else
       print *, "config: Reading ./config_nml.txt..."
       open(unit, file = "config_nml.txt", status = "old", action = "read", &
            position = "rewind")
       read(unit, nml = config_nml)
       close(unit)
       open(unit, file = "SHPC/used_config_nml.txt", status = "replace", &
            action = "write", iostat = iostat, iomsg = iomsg)

       if (iostat /= 0) then
          write(error_unit, fmt = *) "config: Have you created directory SHPC?"
          write(error_unit, fmt = *) trim(iomsg)
          stop 1
       end if

       write(unit, nml = config_nml)
       close(unit)
    end if

    min_area = pi * (min_radius * 1e3)**2

  end subroutine config

end module config_m
